DivGroup

Trait DivGroup 

pub trait DivGroup: MulGroup { }
A marker trait for a Division Group.

This trait is an alias for MulGroup and is used to semantically represent the group of non-zero elements of a Field or DivisionRing under the operation of multiplication.

In such a structure, division a / b is equivalent to multiplication by an inverse, a * b⁻¹. Therefore, a group that supports division is inherently a multiplicative group.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: MulGroup> DivGroup for T